==> ejc-settlementmanage-impl-3.0.0-20230323.014022-192-sources.jar: com/ejianc/business/settlementmanage/vo/TurnoverLeaseSetDetailVO.java <==
package com.ejianc.business.settlementmanage.vo;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 周转租赁结算-子表
 * 
 * @author generator
 * 
 */
public class TurnoverLeaseSetDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private java.lang.Long mid; // 主表id
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long contractId; // 合同id
    private java.lang.String contractName; // 合同名称
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 所属组织id
    private java.lang.String orgName; // 所属组织名称
    private java.lang.Long projectDepartmentId; // 项目部id
    private java.lang.String sort; // 序号
    private java.lang.String billCode; // 来源单据编号
    private Long sourceId; // 来源单据Id
    private java.lang.String encode; // 编码
    private java.lang.String section; // 区段
    private java.lang.String branch; // 分部分项目名称/子项目名称
    private java.lang.String materialCode; // 物资编码
    private java.lang.Long materialCategoryId; // 物资分类id
    private java.lang.String materialCategoryCode; // 物资分类编码
    private java.lang.String materialCategoryName; // 物资分类名称
    private java.lang.String lesseeMaterialsName; // 租赁物资名称
    private java.lang.String specifications; // 规格型号
    private java.lang.String measurementUnit; // 计量单位
    private java.lang.Integer lesseeQuantity; // 租赁数量
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date settleTime; // 本期计算起始时间   租赁起始日期
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date endTime; // 本期计算终止时间  v租赁终止日期
    private java.lang.Integer lesseeTerm; // 本期租赁期长(天)  租赁期长（天）
    private java.math.BigDecimal lesseeUnitprice; // 租赁单价(除税)(元)
    private java.math.BigDecimal taxLesseeUnitprice; // 租赁单价(含税)(元)
    private java.math.BigDecimal lesseeTotalprice; // 租赁合价(除税)(元)
    private java.math.BigDecimal taxLesseeTotalprice; // 租赁合价(含税)(元)
    private java.math.BigDecimal compensateAccount; // 赔偿金额((除税)(元)
    private java.math.BigDecimal taxCompensateAccount; // 赔偿金额(含税)(元)
    private java.math.BigDecimal otherExpenses; // 维修费非等其他费用(除税)(元)
    private java.math.BigDecimal taxOtherExpenses; // 维修费非等其他费用(含税)(元)
    private java.math.BigDecimal monthlyExpenses; // 结算费用((除税)(元)
    private java.math.BigDecimal taxMonthlyExpenses; // 结算费用(含税)(元)
    private java.lang.String remarks; // 备注

    public Long getMid() {
        return mid;
    }

    public void setMid(Long mid) {
        this.mid = mid;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }

    public String getSort() {
        return sort;
    }

    public void setSort(String sort) {
        this.sort = sort;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }

    public String getEncode() {
        return encode;
    }

    public void setEncode(String encode) {
        this.encode = encode;
    }

    public String getSection() {
        return section;
    }

    public void setSection(String section) {
        this.section = section;
    }

    public String getBranch() {
        return branch;
    }

    public void setBranch(String branch) {
        this.branch = branch;
    }

    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public Long getMaterialCategoryId() {
        return materialCategoryId;
    }

    public void setMaterialCategoryId(Long materialCategoryId) {
        this.materialCategoryId = materialCategoryId;
    }

    public String getMaterialCategoryCode() {
        return materialCategoryCode;
    }

    public void setMaterialCategoryCode(String materialCategoryCode) {
        this.materialCategoryCode = materialCategoryCode;
    }

    public String getMaterialCategoryName() {
        return materialCategoryName;
    }

    public void setMaterialCategoryName(String materialCategoryName) {
        this.materialCategoryName = materialCategoryName;
    }

    public String getLesseeMaterialsName() {
        return lesseeMaterialsName;
    }

    public void setLesseeMaterialsName(String lesseeMaterialsName) {
        this.lesseeMaterialsName = lesseeMaterialsName;
    }

    public String getSpecifications() {
        return specifications;
    }

    public void setSpecifications(String specifications) {
        this.specifications = specifications;
    }

    public String getMeasurementUnit() {
        return measurementUnit;
    }

    public void setMeasurementUnit(String measurementUnit) {
        this.measurementUnit = measurementUnit;
    }

    public Integer getLesseeQuantity() {
        return lesseeQuantity;
    }

    public void setLesseeQuantity(Integer lesseeQuantity) {
        this.lesseeQuantity = lesseeQuantity;
    }

    public Date getSettleTime() {
        return settleTime;
    }

    public void setSettleTime(Date settleTime) {
        this.settleTime = settleTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public Integer getLesseeTerm() {
        return lesseeTerm;
    }

    public void setLesseeTerm(Integer lesseeTerm) {
        this.lesseeTerm = lesseeTerm;
    }

    public BigDecimal getLesseeUnitprice() {
        return lesseeUnitprice;
    }

    public void setLesseeUnitprice(BigDecimal lesseeUnitprice) {
        this.lesseeUnitprice = lesseeUnitprice;
    }

    public BigDecimal getTaxLesseeUnitprice() {
        return taxLesseeUnitprice;
    }

    public void setTaxLesseeUnitprice(BigDecimal taxLesseeUnitprice) {
        this.taxLesseeUnitprice = taxLesseeUnitprice;
    }

    public BigDecimal getLesseeTotalprice() {
        return lesseeTotalprice;
    }

    public void setLesseeTotalprice(BigDecimal lesseeTotalprice) {
        this.lesseeTotalprice = lesseeTotalprice;
    }

    public BigDecimal getTaxLesseeTotalprice() {
        return taxLesseeTotalprice;
    }

    public void setTaxLesseeTotalprice(BigDecimal taxLesseeTotalprice) {
        this.taxLesseeTotalprice = taxLesseeTotalprice;
    }

    public BigDecimal getCompensateAccount() {
        return compensateAccount;
    }

    public void setCompensateAccount(BigDecimal compensateAccount) {
        this.compensateAccount = compensateAccount;
    }

    public BigDecimal getTaxCompensateAccount() {
        return taxCompensateAccount;
    }

    public void setTaxCompensateAccount(BigDecimal taxCompensateAccount) {
        this.taxCompensateAccount = taxCompensateAccount;
    }

    public BigDecimal getOtherExpenses() {
        return otherExpenses;
    }

    public void setOtherExpenses(BigDecimal otherExpenses) {
        this.otherExpenses = otherExpenses;
    }

    public BigDecimal getTaxOtherExpenses() {
        return taxOtherExpenses;
    }

    public void setTaxOtherExpenses(BigDecimal taxOtherExpenses) {
        this.taxOtherExpenses = taxOtherExpenses;
    }

    public BigDecimal getMonthlyExpenses() {
        return monthlyExpenses;
    }

    public void setMonthlyExpenses(BigDecimal monthlyExpenses) {
        this.monthlyExpenses = monthlyExpenses;
    }

    public BigDecimal getTaxMonthlyExpenses() {
        return taxMonthlyExpenses;
    }

    public void setTaxMonthlyExpenses(BigDecimal taxMonthlyExpenses) {
        this.taxMonthlyExpenses = taxMonthlyExpenses;
    }

    public String getRemarks() {
        return remarks;
    }

    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }
}

==> ejc-settlementmanage-impl-3.0.0-20251027.062237-321-sources.jar: com/ejianc/business/settlementmanage/vo/TurnoverLeaseSetDetailVO.java <==
package com.ejianc.business.settlementmanage.vo;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.foundation.middlemeasurement.vo.SubcontractingvolumedetailVO;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 周转租赁结算-子表
 * 
 * @author generator
 * 
 */
public class TurnoverLeaseSetDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private java.lang.Long mid; // 主表id
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long contractId; // 合同id
    private java.lang.String contractName; // 合同名称
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 所属组织id
    private java.lang.String orgName; // 所属组织名称
    private java.lang.Long projectDepartmentId; // 项目部id
    private java.lang.String sort; // 序号
    private java.lang.String billCode; // 单据编号
    private java.lang.String sourceBillCode; // 来源单据编号
    private Long sourceId; // 来源单据Id
    private java.lang.String encode; // 编码
    private java.lang.String section; // 区段
    private java.lang.String branch; // 分部分项目名称/子项目名称
    private java.lang.String materialCode; // 物资编码
    private java.lang.Long materialCategoryId; // 物资分类id
    private java.lang.String materialCategoryCode; // 物资分类编码
    private java.lang.String materialCategoryName; // 物资分类名称
    private java.lang.String lesseeMaterialsName; // 租赁物资名称
    private java.lang.String specifications; // 规格型号
    private java.lang.String measurementUnit; // 计量单位
    private java.lang.Integer lesseeQuantity; // 租赁数量
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date settleTime; // 本期计算起始时间   租赁起始日期
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date endTime; // 本期计算终止时间  v租赁终止日期
    private java.lang.Integer lesseeTerm; // 本期租赁期长(天)  租赁期长（天）
    private java.math.BigDecimal lesseeUnitprice; // 租赁单价(除税)(元)
    private java.math.BigDecimal taxLesseeUnitprice; // 租赁单价(含税)(元)
    private java.math.BigDecimal lesseeTotalprice; // 租赁合价(除税)(元)
    private java.math.BigDecimal taxLesseeTotalprice; // 租赁合价(含税)(元)
    private java.math.BigDecimal compensateAccount; // 赔偿金额((除税)(元)
    private java.math.BigDecimal taxCompensateAccount; // 赔偿金额(含税)(元)
    private java.math.BigDecimal otherExpenses; // 维修费非等其他费用(除税)(元)
    private java.math.BigDecimal taxOtherExpenses; // 维修费非等其他费用(含税)(元)
    private java.math.BigDecimal monthlyExpenses; // 结算费用((除税)(元)
    private java.math.BigDecimal taxMonthlyExpenses; // 结算费用(含税)(元)
    private java.lang.String remarks; // 备注
    private java.lang.Integer isFlag; // 标识
    private java.lang.String innercode; // 内码
    private java.lang.String tid;
    private java.lang.String tpid;
    private List<TurnoverLeaseSetDetailVO> children = new ArrayList<>();

    public List<TurnoverLeaseSetDetailVO> getChildren() {
        return children;
    }

    public void setChildren(List<TurnoverLeaseSetDetailVO> children) {
        this.children = children;
    }

    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getTpid() {
        return tpid;
    }

    public void setTpid(String tpid) {
        this.tpid = tpid;
    }

    public String getInnercode() {
        return innercode;
    }

    public void setInnercode(String innercode) {
        this.innercode = innercode;
    }

    public Integer getIsFlag() {
        return isFlag;
    }

    public void setIsFlag(Integer isFlag) {
        this.isFlag = isFlag;
    }

    public String getSourceBillCode() {
        return sourceBillCode;
    }

    public void setSourceBillCode(String sourceBillCode) {
        this.sourceBillCode = sourceBillCode;
    }

    public Long getMid() {
        return mid;
    }

    public void setMid(Long mid) {
        this.mid = mid;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }

    public String getSort() {
        return sort;
    }

    public void setSort(String sort) {
        this.sort = sort;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }

    public String getEncode() {
        return encode;
    }

    public void setEncode(String encode) {
        this.encode = encode;
    }

    public String getSection() {
        return section;
    }

    public void setSection(String section) {
        this.section = section;
    }

    public String getBranch() {
        return branch;
    }

    public void setBranch(String branch) {
        this.branch = branch;
    }

    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public Long getMaterialCategoryId() {
        return materialCategoryId;
    }

    public void setMaterialCategoryId(Long materialCategoryId) {
        this.materialCategoryId = materialCategoryId;
    }

    public String getMaterialCategoryCode() {
        return materialCategoryCode;
    }

    public void setMaterialCategoryCode(String materialCategoryCode) {
        this.materialCategoryCode = materialCategoryCode;
    }

    public String getMaterialCategoryName() {
        return materialCategoryName;
    }

    public void setMaterialCategoryName(String materialCategoryName) {
        this.materialCategoryName = materialCategoryName;
    }

    public String getLesseeMaterialsName() {
        return lesseeMaterialsName;
    }

    public void setLesseeMaterialsName(String lesseeMaterialsName) {
        this.lesseeMaterialsName = lesseeMaterialsName;
    }

    public String getSpecifications() {
        return specifications;
    }

    public void setSpecifications(String specifications) {
        this.specifications = specifications;
    }

    public String getMeasurementUnit() {
        return measurementUnit;
    }

    public void setMeasurementUnit(String measurementUnit) {
        this.measurementUnit = measurementUnit;
    }

    public Integer getLesseeQuantity() {
        return lesseeQuantity;
    }

    public void setLesseeQuantity(Integer lesseeQuantity) {
        this.lesseeQuantity = lesseeQuantity;
    }

    public Date getSettleTime() {
        return settleTime;
    }

    public void setSettleTime(Date settleTime) {
        this.settleTime = settleTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public Integer getLesseeTerm() {
        return lesseeTerm;
    }

    public void setLesseeTerm(Integer lesseeTerm) {
        this.lesseeTerm = lesseeTerm;
    }

    public BigDecimal getLesseeUnitprice() {
        return lesseeUnitprice;
    }

    public void setLesseeUnitprice(BigDecimal lesseeUnitprice) {
        this.lesseeUnitprice = lesseeUnitprice;
    }

    public BigDecimal getTaxLesseeUnitprice() {
        return taxLesseeUnitprice;
    }

    public void setTaxLesseeUnitprice(BigDecimal taxLesseeUnitprice) {
        this.taxLesseeUnitprice = taxLesseeUnitprice;
    }

    public BigDecimal getLesseeTotalprice() {
        return lesseeTotalprice;
    }

    public void setLesseeTotalprice(BigDecimal lesseeTotalprice) {
        this.lesseeTotalprice = lesseeTotalprice;
    }

    public BigDecimal getTaxLesseeTotalprice() {
        return taxLesseeTotalprice;
    }

    public void setTaxLesseeTotalprice(BigDecimal taxLesseeTotalprice) {
        this.taxLesseeTotalprice = taxLesseeTotalprice;
    }

    public BigDecimal getCompensateAccount() {
        return compensateAccount;
    }

    public void setCompensateAccount(BigDecimal compensateAccount) {
        this.compensateAccount = compensateAccount;
    }

    public BigDecimal getTaxCompensateAccount() {
        return taxCompensateAccount;
    }

    public void setTaxCompensateAccount(BigDecimal taxCompensateAccount) {
        this.taxCompensateAccount = taxCompensateAccount;
    }

    public BigDecimal getOtherExpenses() {
        return otherExpenses;
    }

    public void setOtherExpenses(BigDecimal otherExpenses) {
        this.otherExpenses = otherExpenses;
    }

    public BigDecimal getTaxOtherExpenses() {
        return taxOtherExpenses;
    }

    public void setTaxOtherExpenses(BigDecimal taxOtherExpenses) {
        this.taxOtherExpenses = taxOtherExpenses;
    }

    public BigDecimal getMonthlyExpenses() {
        return monthlyExpenses;
    }

    public void setMonthlyExpenses(BigDecimal monthlyExpenses) {
        this.monthlyExpenses = monthlyExpenses;
    }

    public BigDecimal getTaxMonthlyExpenses() {
        return taxMonthlyExpenses;
    }

    public void setTaxMonthlyExpenses(BigDecimal taxMonthlyExpenses) {
        this.taxMonthlyExpenses = taxMonthlyExpenses;
    }

    public String getRemarks() {
        return remarks;
    }

    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }
}
